==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24ButtonBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$ButtonBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c174c13db1219998 javax_swing_plaf_basic_BasicBorders__24ButtonBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern void _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*lightHighlight;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24ButtonBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24ButtonBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$ButtonBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class c174c13db1219998 javax_swing_plaf_basic_BasicBorders__24ButtonBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*lightHighlight;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24ButtonBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24ButtonBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24ButtonBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24ButtonBorder_H_ */
